#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2

# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2019-11-04
#
#
# Check_MK cisco_flash WATO plugin
#
# 2019-11-04: initial release
# 2021-07-31: rewritten for CMK 2.0
#
#
from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    TextAscii,
    Tuple,
)

from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    RulespecGroupCheckParametersNetworking,
    rulespec_registry,
)


def _parameter_valuespec_cisco_flash():
    return Dictionary(
        elements=[
            ('levels_upper_percent',
             Tuple(
                 title=_('Levels for usage in %'),
                 elements=[
                     Integer(title=_('Warning at'), unit='%', default_value=85, minvalue=0, maxvalue=100),
                     Integer(title=_('Critical at'), unit='%', default_value=90, minvalue=0, maxvalue=100)
                 ],

             )),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name='cisco_flash',
        group=RulespecGroupCheckParametersNetworking,
        item_spec=lambda: TextAscii(title=_('Partition specific configuration'), ),
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_cisco_flash,
        title=lambda: _('Cisco flash'),
    ))
