#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2

# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2019-10-28
#
# Cisco flash metrics plugin
#
# change log
# 2019-10-28: initial release
# 2021-07-31: rewritten for CMK 2.0


from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    HostRulespec,
    rulespec_registry,
)
from cmk.gui.valuespec import (
    Dictionary,
    FixedValue,
    ListChoice,
)

from cmk.gui.plugins.wato.inventory import (
    RulespecGroupInventory,
)

_inv_cisco_flash_cfl_device_remove_columns = [
    ('minpartitionsize', 'min. partition size (MB)'),
    ('maxprtitions', 'max. partitions'),
    ('chipcount', 'Chip count'),
    ('controller', 'Controller'),
    ('programmingjumper', 'Programming jumper'),
    ('inittime', 'Init time'),
    ('removable', 'Removable'),
    ('physentindex', 'Phys entity index'),
    ('nameextended', 'Name extended'),
]

_inv_cisco_flash_cfl_partition_remove_columns = [
    ('startchip', 'Start chip'),
    ('endchip', 'End chip'),
    ('crcsumalgo', 'Checksumm algorithm'),
    ('status', 'Status'),
    ('upgrademethod', 'Upgrade method'),
    ('neederasure', 'Need erasure'),
    ('filenamelength', 'File name length'),
    ('lowspacenotifythreshold', 'Low space notify threshold (%)'),
]

_inv_cisco_flash_cfl_chip_remove_columns = [
    ('code', 'Code'),
    ('writeretries', 'Write retries'),
    ('eraseretries', 'Erase retries'),
    ('maxwriteretries', 'max. write retries'),
    ('maxeraseretries', 'max. erasure retries'),
]


def _valuespec_inv_cisco_flash():
    return Dictionary(
        title=_('Cisco flash inventory'),
        elements=[
            ('cflDeviceDisable',
             FixedValue(
                 True,
                 title=_('disable Flash device inventory'),
             )),
            ('cflPartitionDisable',
             FixedValue(
                 True,
                 title=_('disable Flash partition inventory'),
             )),
            ('cflChipDisable',
             FixedValue(
                 True,
                 title=_('disable Flash chips inventory'),
             )),
            ('cflDeviceRemovecolumns',
             ListChoice(
                 title=_('list of columns to remove from flash devices'),
                 help=_('information to remove from inventory'),
                 choices=_inv_cisco_flash_cfl_device_remove_columns,
                 default_value=[
                     'chipcount',
                     'controller',
                     'programmingjumper',
                     'inittime',
                     'physentindex',
                     'nameextended',
                 ],
             )),
            ('cflPartitionRemovecolumns',
             ListChoice(
                 title=_('list of columns to remove from flash partitions'),
                 help=_('information to remove from inventory'),
                 choices=_inv_cisco_flash_cfl_partition_remove_columns,
                 default_value=[
                     'startchip',
                     'endchip',
                 ],
             )),
            ('cflChipRemovecolumns',
             ListChoice(
                 title=_('list of columns to remove from flash chips'),
                 help=_('information to remove from inventory'),
                 choices=_inv_cisco_flash_cfl_chip_remove_columns,
                 default_value=[
                     'code',
                     'writeretries',
                     'eraseretries',
                     'maxwriteretries',
                     'maxeraseretries'
                 ],
             )),
        ],
    )


rulespec_registry.register(
    HostRulespec(
        group=RulespecGroupInventory,
        match_type='dict',
        name='inv_parameters:inv_cisco_flash',
        valuespec=_valuespec_inv_cisco_flash,
    ))
